# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.2] - 2026-02-23

### Added

- Added Dependabot for automated dependency updates.
- Added automated PyPI versioning and publishing.

### Changed

- Removed `variables` wrapper from `to_toml_dict` return value.


## [0.1.1] - 2026-02-17

### Added

- Add TOML output format for vulnerabilities

### Changed

- Extracted CLI logic into reusable `commands` module


## [0.1.0] - 2026-02-16

### Added

- Search vulnerabilities in NVD and OSV by package/version/ecosystem.
- Discover potentially vulnerable products in NVD via keyword-based CPE search.
- Scan `CycloneDX` SBOM files and return vulnerable packages with associated vulnerabilities.
- CLI output for vulnerability results.
